@@ -1,6 +1,6 @@
 # Samizdat message controller
 #
-#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2011  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
@@ -158,32 +158,6 @@ class MessageController < Controller
     )
   end
 
-  def describe
-    assert_post
-
-    @message = Message.new(site, nil)
-    set_creator
-    set_content
-    set_lang
-    set_open
-
-    event = Event.cached(site, @id)
-    event.description and raise UserError,
-      _('This event already has a description')
-    resource = Resource.new(@request, @id)
-
-    post(
-      :title => _('Describe Event'),
-      :edit => Proc.new {
-        @message.insert!
-        event.description = @message.id
-        event.save!
-      },
-      :redirect => Proc.new { @id },
-      :footer => box(resource.title, resource.full)
-    )
-  end
-
   def edit
     assert_post
 
@@ -642,7 +616,7 @@ class MessageController < Controller
   #
   def save(log_action = nil)
     @request.assert_action_confirmed
-    db.transaction do |db|
+    db.transaction do
       log_moderation(log_action) if log_action
       yield
       @upload.status = 'confirmed' if @upload
