@@ -33,7 +33,7 @@ class Controller
                :icon => config['site']['icon'] }
 
     # JavaScript libraries
-    @js = [ 'flashembed' ]
+    @js = []
   end
 
   def render
@@ -75,7 +75,7 @@ class Controller
     (@session.member and @id) or raise RuntimeError,
       'Not enough data to log moderation'
 
-    db[:Moderation].insert(
+    db[:moderation].insert(
       :moderator => @session.member,
       :action => action,
       :resource => @id
