@@ -1,6 +1,6 @@
 # Samizdat engine singleton objects
 #
-#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2011  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
@@ -18,7 +18,7 @@ class DefaultConfig
   # /usr/share, /usr/local/share, and current directory.
   #
   DIRS = [ '/etc/samizdat/',
-           Config::CONFIG['datadir'] + '/samizdat/',
+           RbConfig::CONFIG['datadir'].untaint + '/samizdat/',
            '/usr/local/share/samizdat/',
            '.' ]
 
