@@ -39,6 +39,10 @@ class Plugin
   def depends
     []
   end
+
+  def self.register_as(type)
+    PluginClasses.instance[type] = self
+  end
 end
 
 # singleton Hash mapping plugin names to classes
@@ -47,6 +51,12 @@ class PluginClasses < Hash
   include Singleton
 end
 
+# inline formats that need a link to view source
+#
+class InlineFormat < Hash
+  include Singleton
+end
+
 # plugins configuration for a Samizdat site
 #
 class Plugins
