@@ -9,7 +9,11 @@
 # vim: et sw=2 sts=2 ts=8 tw=0
 
 require 'samizdat'
-require 'erb'
+begin
+  require 'erubis'
+rescue LoadError
+  require 'erb'
+end
 
 class View
   def initialize(site, template)
@@ -33,8 +37,25 @@ class View
 
   private
 
-  def set_renderer(location)
-    body = File.open(location) {|f| f.read }
-    @erb = ERB.new(body.untaint, nil, '>')
+  if defined? Erubis
+    CACHE_DIR = '/var/cache/samizdat/erubis'
+    if File.directory?(CACHE_DIR) and File.writable?(CACHE_DIR)
+      def set_renderer(location)
+        cachename = File.join(CACHE_DIR, digest(location) + '_' + File.basename(location))
+        @erb = Erubis::FastEruby.load_file(location, :cachename => cachename)
+      end
+
+    else
+      def set_renderer(location)
+        body = File.open(location) {|f| f.read }
+        @erb = Erubis::FastEruby.new(body.untaint)
+      end
+    end
+
+  else
+    def set_renderer(location)
+      body = File.open(location) {|f| f.read }
+      @erb = ERB.new(body.untaint, nil, '>')
+    end
   end
 end
