@@ -1,6 +1,6 @@
 # Samizdat data content plugin superclass
 #
-#   Copyright (c) 2002-2009  Dmitry Borodaenko <angdraug@debian.org>
+#   Copyright (c) 2002-2011  Dmitry Borodaenko <angdraug@debian.org>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
@@ -24,7 +24,7 @@ class ContentFilePlugin < Plugin
   #
   def rewrite_link(request, mode, content, element)
     attribute_name = LINK_ATTRIBUTE[element.name]
-    element.attributes[attribute_name] = content.file.href if attribute_name
+    element[attribute_name] = content.file.href if attribute_name
   end
 
   # invoked when new content file is uploaded
