@@ -51,6 +51,11 @@ class ContentInlinePlugin < Plugin
     end
   end
 
+  def self.register_inline_format(format, name)
+    register_as name
+    InlineFormat.instance[format] = name
+  end
+
   private
 
   CUT_MARK_DEFAULT = '$$$'
