@@ -12,14 +12,13 @@ require 'samizdat'
 require 'samizdat/plugins/content_file'
 require 'fileutils'
 require 'nokogiri'
-
-# don't allow RMagic to second-guess ld.so
-RMAGICK_BYPASS_VERSION_TEST = true
-require 'RMagick'
+require 'rmagick'
 
 class ImagePlugin < ContentFilePlugin
   include Magick
 
+  register_as 'image'
+
   def match?(format)
     :image == format_type(format)
   end
@@ -128,5 +127,3 @@ class ImagePlugin < ContentFilePlugin
     end
   end
 end
-
-PluginClasses.instance['image'] = ImagePlugin
