@@ -12,6 +12,8 @@ require 'samizdat'
 require 'samizdat/plugins/access'
 
 class RolePlugin < AccessPlugin
+  register_as 'role'
+
   def match?(member, action)
     @options.each do |role, actions|
       return true if
@@ -33,7 +35,7 @@ class RolePlugin < AccessPlugin
     if member.id.kind_of?(Integer)
       member.access['role'].push('member')
 
-      db[:Role].filter(:member => member.id).select(:role).distinct.each do |r|
+      db[:role].filter(:member => member.id).select(:role).distinct.each do |r|
         member.access['role'].push(r[:role])
       end
     end
@@ -63,5 +65,3 @@ class RolePlugin < AccessPlugin
     [ _('guest'), _('member'), _('moderator') ]
   end
 end
-
-PluginClasses.instance['role'] = RolePlugin
